pub struct ArcSet {
pub i: u32,
pub aar: ArcAuthResults,
pub ams: ArcMessageSignature,
pub seal: ArcSeal,
pub raw_aar: String,
pub raw_ams: String,
pub raw_seal: String,
}Expand description
One ARC instance’s triplet of headers.
Fields
i: u32Instance number (1..=50).
aar: ArcAuthResultsParsed ARC-Authentication-Results header.
ams: ArcMessageSignatureParsed ARC-Message-Signature header.
seal: ArcSealParsed ARC-Seal header.
raw_aar: StringVerbatim header values, in the order they appeared in the original message. Needed by the seal verifier (it canonicalizes the prior chain headers as input to its hash).
raw_ams: Stringsee Self::raw_aar.
raw_seal: Stringsee Self::raw_aar.